@@ -140,42 +140,63 @@ class Arbiter(object):
                     self.log.error("should be a non GUNICORN environnement")
                 else:
                     raise
-
+                    
         for i in range(5):
             try:
                 sock = self.init_socket(addr)
                 self.LISTENER = sock
-                break
+                break            
             except socket.error, e:
                 if e[0] == errno.EADDRINUSE:
                     self.log.error("Connection in use: %s" % str(addr))
                 if i < 5:
                     self.log.error("Retrying in 1 second.")
-                time.sleep(1)
-        if self.LISTENER: 
-            self.log.info("Listen on %s:%s" % self.LISTENER.getsockname())
+                    time.sleep(1)
+          
+        if self.LISTENER:
+            try:
+                self.log.info("Listen on %s:%s" % self.LISTENER.getsockname())
+            except TypeError:
+                self.log.info("Listen on %s" % self.LISTENER.getsockname())
+        else:
+            self.log.error("Can't connect to %s" % str(addr))
+            sys.exit(1)
                 
     def init_socket_fromfd(self, fd, address):
-        sock = socket.fromfd(fd, socket.AF_INET, socket.SOCK_STREAM)
-        self.set_sockopts(sock)
+        if isinstance(address, basestring):
+            sock = socket.fromfd(fd, socket.AF_UNIX, socket.SOCK_STREAM)
+        else:
+            sock = socket.fromfd(fd, socket.AF_INET, socket.SOCK_STREAM)
+            self.set_tcp_sockopts(sock)
+        self.set_sockopts(sock, address)
         return sock
 
     def init_socket(self, address):
-        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        self.set_sockopts(sock)
-        sock.bind(address)
-        sock.listen(2048)
+        if isinstance(address, basestring):
+            try:
+                os.remove(address)
+            except OSError, e:
+                pass
+            sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
+        else:
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            self.set_tcp_sockopts(sock)
+        self.set_sockopts(sock, address)
         return sock
         
-    def set_sockopts(self, sock):
-        sock.setblocking(0)
-        sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-        sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+    def set_tcp_sockopts(self, sock):
         if hasattr(socket, "TCP_CORK"):
             sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_CORK, 1)
         elif hasattr(socket, "TCP_NOPUSH"):
             sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NOPUSH, 1)
-
+        sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+        
+    def set_sockopts(self, sock, address):
+        sock.setblocking(0)
+        sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+        sock.bind(address)
+        sock.listen(2048)
+        
     def run(self):
         self.start()
         self.manage_workers()
@@ -204,11 +225,12 @@ class Arbiter(object):
             except StopIteration:
                 break
             except KeyboardInterrupt:
-                self.stop()
-                sys.exit(-1)
+                break
             except Exception:
                 self.log.info("Unhandled exception in main loop.")
                 self.stop(False)
+                if self.pidfile:
+                    self.unlink_pidfile(self.pidfile)
                 sys.exit(-1)
 
         self.stop()
@@ -338,7 +360,7 @@ class Arbiter(object):
                 continue
 
             worker = Worker(i, self.pid, self.LISTENER, self.modname,
-                        self.timeout/2, self.debug)
+                        self.timeout/2.0, self.debug)
             pid = os.fork()
             if pid != 0:
                 self.WORKERS[pid] = worker
