@@ -22,7 +22,7 @@ class Worker(object):
 
     SIGNALS = map(
         lambda x: getattr(signal, "SIG%s" % x),
-        "HUP QUIT INT TERM TTIN TTOU USR1 USR2 WINCH".split()
+        "CHLD HUP QUIT INT TERM TTIN TTOU USR1 USR2 WINCH".split()
     )
     
     PIPE = []
@@ -34,23 +34,13 @@ class Worker(object):
         self.debug = debug
         self.socket = socket
         self.timeout = timeout
-        fd, tmpname = tempfile.mkstemp()
-        self.tmp = os.fdopen(fd, "r+b")
+        self.fd, tmpname = tempfile.mkstemp()
+        self.tmp = os.fdopen(self.fd, "r+b")
         self.tmpname = tmpname
         self.app = app
         self.alive = True
         self.log = logging.getLogger(__name__)
         self.spinner = 0
-
-        # init pipe
-        self.PIPE = os.pipe()
-        map(util.set_non_blocking, self.PIPE)
-        map(util.close_on_exec, self.PIPE)
-        
-        # prevent inherientence
-        util.close_on_exec(self.socket)
-        util.close_on_exec(fd)
-        
         self.address = self.socket.getsockname()
 
     def __str__(self):
@@ -86,9 +76,21 @@ class Worker(object):
             os.fchmod(self.tmp.fileno(), self.spinner)
         else:
             os.chmod(self.tmpname, self.spinner)
+            
+    def init_process(self):
+        # init pipe
+        self.PIPE = os.pipe()
+        map(util.set_non_blocking, self.PIPE)
+        map(util.close_on_exec, self.PIPE)
+        
+        # prevent inherientence
+        util.close_on_exec(self.socket)
+        util.close_on_exec(self.fd)
+        self.init_signals()
+        
     
     def run(self):
-        self.init_signals()
+        self.init_process()
         self.nr = 0
 
         # self.socket appears to lose its blocking status after
@@ -125,8 +127,11 @@ class Worker(object):
             except select.error, e:
                 if e[0] == errno.EINTR:
                     continue
-                if e[0] == errno.EBADF and self.nr < 0:
-                    continue
+                if e[0] == errno.EBADF:
+                    if self.nr < 0:
+                        continue
+                    else:
+                        return
                 raise
 
     def handle(self, client, addr):
